==> nextcloud-app-calendar-1%3A2.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/oc.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Adieusiatz, ",
    "Open »%s«" : "Dobrir « %s »",
    "Cheers!" : "A lèu !",
    "Upcoming events" : "Eveniments venents",
    "Calendar" : "Calendièr",
    "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
    "Previous day" : "Jorn passat",
    "Previous week" : "Setmana passada",
    "Previous month" : "Mes passat",
    "Next day" : "Jorn seguent",
    "Next week" : "Setmana seguenta",
    "Next month" : "Mes seguent",
    "+ New event" : "+ eveniment novèl",
    "Today" : "Uèi",
    "Day" : "Jorn",
    "Week" : "Aquesta setmana",
    "Month" : "Mes",
    "List" : "Tièra",
    "Untitled calendar" : "Calendièr sens nom",
    "Edit name" : "Modificar lo nom",
    "Saving name …" : "Enregistrament del nom …",
    "Edit color" : "Modificar la color",
    "Saving color …" : "Enregistrament de la color …",
    "Copy private link" : "Copiar lo ligam privat",
    "Download" : "Telecargar",
    "Delete" : "Suprimir",
    "Share link" : "Partejar lo ligam",
    "Publish calendar" : "Publicar lo calendièr",
    "Copy public link" : "Copiar lo ligam public",
    "Copied link" : "Ligam copiat",
    "Copied code" : "Còdi copiat",
    "Could not copy code" : "Se poguèt pas copiar lo còdi",
    "can edit" : "pòt modificar",
    "+ New calendar" : "+ Calendièr novèl",
    "New calendar" : "Calendièr novèl",
    "Import calendars" : "Importar de calendièrs",
    "Filename" : "Nom de fichièr",
    "Cancel" : "Anullar",
    "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
    "Automatic" : "Automatic",
    "or" : "o",
    "Navigation" : "Navegacion",
    "Views" : "Vistas",
    "Day view" : "Mostrar un jorn",
    "Week view" : "Monstrar una setmana",
    "Month view" : "Monstrar un mes",
    "Actions" : "Accions",
    "Show weekends" : "Monstrar las dimenjadas",
    "Reminder" : "Recòrd",
    "Notification" : "Notificacion",
    "Email" : "Adreça corrièl",
    "Audio notification" : "Notificacion àudio",
    "Other notification" : "Autras notificacions",
    "Edit time" : "Modificar l’ora",
    "Remove reminder" : "Suprimir lo rapèl",
    "on" : "lo",
    "at" : "a",
    "+ Add reminder" : "+ Apondre un rapèl",
    "_second_::_seconds_" : ["segonda","segondas"],
    "_minute_::_minutes_" : ["minuta","minutas"],
    "_hour_::_hours_" : ["ora","oras"],
    "_day_::_days_" : ["jorn","jorns"],
    "_week_::_weeks_" : ["setmana","setmanas"],
    "Busy" : "Ocupat",
    "Unknown" : "Desconegut",
    "All day" : "Tota la jornada",
    "Repeat" : "Repetir",
    "Save" : "Salvar",
    "Edit" : "Modificar",
    "never" : "pas jamai",
    "after" : "aprèp",
    "_time_::_times_" : ["còp","còps"],
    "first" : "primièr",
    "third" : "tresen",
    "fourth" : "quatren",
    "fifth" : "cinquen",
    "last" : "darrièr",
    "_month_::_months_" : ["mes","mese"],
    "_year_::_years_" : ["annada","annadas"],
    "Monday" : "diluns",
    "Suggestions" : "Suggestions",
    "Add resource" : "Apondre ressorsa",
    "More" : "Mai",
    "Update" : "Metre a jorn",
    "Pick a time" : "Causir una ora",
    "Pick a date" : "Causir una data",
    "from {formattedDate}" : "a partir de {formattedDate}",
    "to {formattedDate}" : "cap a {formattedDate}",
    "Type to search time zone" : "Picar per cercar un fus orari",
    "Global" : "Global",
    "Personal" : "Personal",
    "[Today]" : "[Uèi]",
    "[Tomorrow]" : "[Deman]",
    "[Yesterday]" : "[Ièr]",
    "[Last] dddd" : "dddd [passat]",
    "Details" : "Detalhs",
    "Attendees" : "Convidats",
    "Close" : "Tampar",
    "Download {name}" : "Telecargar {name}",
    "Anniversary" : "Anniversari",
    "Appointment" : "Rendetz-vos",
    "Business" : "Afar",
    "Education" : "Educacion",
    "Holiday" : "Vacanças",
    "Meeting" : "Reünion",
    "Travel" : "Viatge",
    "Vacation" : "Vacanças",
    "Daily" : "Cada jorn",
    "Weekly" : "Cada setmana",
    "Monthly" : "Cada mes",
    "Yearly" : "Cada an",
    "_Every %n day_::_Every %n days_" : ["Cada %n jorn","Cada %n jorns"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
    "_%n time_::_%n times_" : ["%n còp","%n còps"],
    "Untitled event" : "Eveniment sens nom",
    "Untitled task" : "Prètzfach sens nom",
    "Location" : "Emplaçament",
    "Add a location" : "Apondre un lòc",
    "Description" : "Descripcion",
    "Add a description" : "Apondre una descripcion",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Tentative" : "Provisòri",
    "Canceled" : "Anullat",
    "Categories" : "Categorias",
    "Custom color" : "Color personalizada",
    "Presentation" : "Presentacion",
    "Movie" : "Film",
    "Cinema" : "Cinèma",
    "Mail" : "Mail",
    "Gaming" : "Vidèo-jòc",
    "Bicycle" : "Bicicleta",
    "Fishing" : "Pesca",
    "Hiking" : "Escalada",
    "Art" : "Arts",
    "Museum" : "Musèu",
    "Studying" : "Estudis",
    "Doctor" : "Mètge",
    "Health" : "Santat",
    "Dentist" : "Dentista",
    "Training" : "Entraïnament",
    "Sports" : "Espòrt",
    "Written test" : "Test escrich",
    "Oral test" : "Test oral",
    "Christmas" : "Nadal",
    "Conference" : "Conferéncia",
    "Pizza" : "Pizza",
    "Travelling" : "Viatge",
    "Party" : "Fèsta",
    "Shopping" : "Crompas"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-calendar-1%3A5.0.8-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/oc.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Adieusiatz, ",
    "Open »%s«" : "Dobrir « %s »",
    "Cheers!" : "A lèu !",
    "Upcoming events" : "Eveniments venents",
    "Calendar" : "Calendièr",
    "Appointments" : "Rendetz-vos",
    "Confirm" : "Confirmar",
    "Description:" : "Descripcion :",
    "Date:" : "Data :",
    "Where:" : "Ont :",
    "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
    "Previous day" : "Jorn passat",
    "Previous week" : "Setmana passada",
    "Previous month" : "Mes passat",
    "Next day" : "Jorn seguent",
    "Next week" : "Setmana seguenta",
    "Next month" : "Mes seguent",
    "Today" : "Uèi",
    "Day" : "Jorn",
    "Week" : "Aquesta setmana",
    "Month" : "Mes",
    "Year" : "Annada",
    "List" : "Tièra",
    "Preview" : "Apercebut",
    "Copy link" : "Copiar lo ligam",
    "Edit" : "Modificar",
    "Delete" : "Suprimir",
    "Untitled calendar" : "Calendièr sens nom",
    "Calendars" : "Calendièrs",
    "Add new" : "Apondre novèl",
    "New calendar" : "Calendièr novèl",
    "Name for new calendar" : "Nom del calendièr novèl",
    "Creating calendar …" : "Creacion del calendièr…",
    "Copied link" : "Ligam copiat",
    "Export" : "Exportar",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaurar",
    "Delete permanently" : "Suprimir definitivament",
    "Hidden" : "Amagat",
    "Share link" : "Partejar lo ligam",
    "Copy public link" : "Copiar lo ligam public",
    "Copied code" : "Còdi copiat",
    "Could not copy code" : "Se poguèt pas copiar lo còdi",
    "Delete share link" : "Suprimir lo ligam de partatge",
    "Deleting share link …" : "Supression del ligam de partatge …",
    "can edit" : "pòt modificar",
    "Save" : "Salvar",
    "Import calendars" : "Importar de calendièrs",
    "Filename" : "Nom de fichièr",
    "Cancel" : "Anullar",
    "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
    "Automatic" : "Automatic",
    "or" : "o",
    "Navigation" : "Navegacion",
    "Views" : "Vistas",
    "Day view" : "Mostrar un jorn",
    "Week view" : "Monstrar una setmana",
    "Month view" : "Monstrar un mes",
    "Actions" : "Accions",
    "Show weekends" : "Monstrar las dimenjadas",
    "0 minutes" : "0 minuta",
    "Location" : "Emplaçament",
    "Description" : "Descripcion",
    "Visibility" : "Visibilitat",
    "Duration" : "Durada",
    "to" : "a",
    "Add" : "Apondre",
    "Monday" : "Diluns",
    "Tuesday" : "Dimars",
    "Wednesday" : "Dimècres",
    "Thursday" : "Dijòus",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Dimenge",
    "Update" : "Metre a jorn",
    "Your name" : "Vòstre nom",
    "Your email address" : "Vòstra adreça electronica",
    "Reminder" : "Recòrd",
    "Notification" : "Notificacion",
    "Email" : "Adreça corrièl",
    "Audio notification" : "Notificacion àudio",
    "Other notification" : "Autras notificacions",
    "Edit time" : "Modificar l’ora",
    "Remove reminder" : "Suprimir lo rapèl",
    "on" : "lo",
    "at" : "a",
    "+ Add reminder" : "+ Apondre un rapèl",
    "_second_::_seconds_" : ["segonda","segondas"],
    "_minute_::_minutes_" : ["minuta","minutas"],
    "_hour_::_hours_" : ["ora","oras"],
    "_day_::_days_" : ["jorn","jorns"],
    "_week_::_weeks_" : ["setmana","setmanas"],
    "Delete file" : "Suprimir fichièr",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Available" : "Disponible",
    "Free" : "Liure",
    "Busy (tentative)" : "Ocupat (provisòri)",
    "Busy" : "Ocupat",
    "Out of office" : "Fòra del burèu",
    "Unknown" : "Desconegut",
    "Room name" : "Nom de la sala",
    "Accept" : "Acceptar",
    "Decline" : "Declinar",
    "Tentative" : "Provisòri",
    "Attendees" : "Convidats",
    "Remove group" : "Suprimir lo grop",
    "Remove color" : "Suprimir la color",
    "Event title" : "Títol de l’eveniment",
    "From" : "De",
    "All day" : "Tota la jornada",
    "Repeat" : "Repetir",
    "never" : "pas jamai",
    "after" : "aprèp",
    "_time_::_times_" : ["còp","còps"],
    "first" : "primièr",
    "third" : "tresen",
    "fourth" : "quatren",
    "fifth" : "cinquen",
    "last" : "darrièr",
    "_month_::_months_" : ["mes","mese"],
    "_year_::_years_" : ["annada","annadas"],
    "weekday" : "dimenjada",
    "weekend day" : "jorn de la setmana",
    "Suggestions" : "Suggestions",
    "Add resource" : "Apondre ressorsa",
    "available" : "disponible",
    "unavailable" : "indisponible",
    "Room type" : "Tipe de sala",
    "Any" : "Quina que siá",
    "Pick a time" : "Causir una ora",
    "Pick a date" : "Causir una data",
    "from {formattedDate}" : "a partir de {formattedDate}",
    "to {formattedDate}" : "cap a {formattedDate}",
    "Type to search time zone" : "Picar per cercar un fus orari",
    "Global" : "Global",
    "Subscribe" : "S'abonar",
    "Personal" : "Personal",
    "Details" : "Detalhs",
    "Close" : "Tampar",
    "Untitled event" : "Eveniment sens nom",
    "Anniversary" : "Anniversari",
    "Appointment" : "Rendetz-vos",
    "Business" : "Afar",
    "Education" : "Educacion",
    "Holiday" : "Vacanças",
    "Meeting" : "Reünion",
    "Travel" : "Viatge",
    "Vacation" : "Vacanças",
    "Daily" : "Cada jorn",
    "Weekly" : "Cada setmana",
    "Monthly" : "Cada mes",
    "Yearly" : "Cada an",
    "_Every %n day_::_Every %n days_" : ["Cada %n jorn","Cada %n jorns"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n an","Cada %n ans"],
    "_%n time_::_%n times_" : ["%n còp","%n còps"],
    "Untitled task" : "Prètzfach sens nom",
    "Other" : "Autre",
    "Add a location" : "Apondre un lòc",
    "Add a description" : "Apondre una descripcion",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Canceled" : "Anullat",
    "Categories" : "Categorias",
    "Custom color" : "Color personalizada",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "User not found" : "Utilizaire pas trobat",
    "Create a new event" : "Crear un eveniment novèl",
    "[Today]" : "[Uèi]",
    "[Tomorrow]" : "[Deman]",
    "[Yesterday]" : "[Ièr]",
    "[Last] dddd" : "dddd [passat]"
},
"nplurals=2; plural=(n > 1);");
